@@ -1,22 +1,19 @@
 # frozen_string_literal: true
 
-# $Id: RMagick.rb,v 1.84 2009/09/15 22:08:41 rmagick Exp $
+# $Id: rmagick_internal.rb,v 1.84 2009/09/15 22:08:41 rmagick Exp $
 #==============================================================================
 #                  Copyright (C) 2009 by Timothy P. Hunter
-#   Name:       RMagick.rb
+#   Name:       rmagick_internal.rb
 #   Author:     Tim Hunter
 #   Purpose:    Extend Ruby to interface with ImageMagick.
 #   Notes:      RMagick2.so defines the classes. The code below adds methods
 #               to the classes.
 #==============================================================================
 
-if RUBY_PLATFORM =~ /mingw/i
-  begin
-    require 'ruby_installer'
-    ENV['PATH'].split(File::PATH_SEPARATOR).grep(/ImageMagick/i).each do |path|
-      RubyInstaller::Runtime.add_dll_directory(path) if File.exist?(File.join(path, 'CORE_RL_magick_.dll')) || File.exist?(File.join(path, 'CORE_RL_MagickCore_.dll'))
-    end
-  rescue LoadError
+if RUBY_PLATFORM.match?(/mingw/i)
+  require 'ruby_installer'
+  ENV['PATH'].split(File::PATH_SEPARATOR).grep(/ImageMagick/i).each do |path|
+    RubyInstaller::Runtime.add_dll_directory(path) if File.exist?(File.join(path, 'CORE_RL_magick_.dll')) || File.exist?(File.join(path, 'CORE_RL_MagickCore_.dll'))
   end
 end
 
@@ -51,11 +48,11 @@ module Magick
     #   p Magick.formats
     #   => {"3FR"=>" r-+", "3G2"=>" r-+", "3GP"=>" r-+", "A"=>"*rw+",
     #   ...
-    def formats
+    def formats(&block)
       formats = init_formats
 
-      if block_given?
-        formats.each { |k, v| yield k, v }
+      if block
+        formats.each(&block)
         self
       else
         formats
@@ -140,7 +137,7 @@ module Magick
 
     # Convert object to a geometry string
     def to_s
-      str = String.new
+      str = +''
       if @width > 0
         fmt = @width.truncate == @width ? '%d' : '%.2f'
         str << sprintf(fmt, @width)
@@ -227,7 +224,7 @@ module Magick
 
     def enquote(str)
       str = to_string(str)
-      if str.length > 2 && /\A(?:\"[^\"]+\"|\'[^\']+\'|\{[^\}]+\})\z/.match(str)
+      if str.length > 2 && /\A(?:"[^\"]+"|'[^\']+'|\{[^\}]+\})\z/.match(str)
         str
       else
         '"' + str + '"'
@@ -277,7 +274,7 @@ module Magick
 
     # Draw a bezier curve.
     def bezier(*points)
-      if points.length.zero?
+      if points.empty?
         Kernel.raise ArgumentError, 'no points specified'
       elsif points.length.odd?
         Kernel.raise ArgumentError, 'odd number of arguments specified'
@@ -479,7 +476,7 @@ module Magick
 
     # Draw a polygon
     def polygon(*points)
-      if points.length.zero?
+      if points.empty?
         Kernel.raise ArgumentError, 'no points specified'
       elsif points.length.odd?
         Kernel.raise ArgumentError, 'odd number of points specified'
@@ -489,7 +486,7 @@ module Magick
 
     # Draw a polyline
     def polyline(*points)
-      if points.length.zero?
+      if points.empty?
         Kernel.raise ArgumentError, 'no points specified'
       elsif points.length.odd?
         Kernel.raise ArgumentError, 'odd number of points specified'
@@ -504,7 +501,7 @@ module Magick
     # pop('pattern')
 
     def pop(*what)
-      if what.length.zero?
+      if what.empty?
         primitive 'pop graphic-context'
       else
         primitive 'pop ' + what.map { |x| to_string(x) }.join(' ')
@@ -517,7 +514,7 @@ module Magick
     # push('gradient')
     # push('pattern')
     def push(*what)
-      if what.length.zero?
+      if what.empty?
         primitive 'push graphic-context'
       else
         primitive 'push ' + what.map { |x| to_string(x) }.join(' ')
@@ -573,7 +570,7 @@ module Magick
 
     # Specify a stroke dash pattern
     def stroke_dasharray(*list)
-      if list.length.zero?
+      if list.empty?
         primitive 'stroke-dasharray none'
       else
         list.map! { |x| Float(x) }.each do |x|
@@ -622,7 +619,7 @@ module Magick
     def text(x, y, text)
       text = to_string(text)
       Kernel.raise ArgumentError, 'missing text argument' if text.empty?
-      if text.length > 2 && /\A(?:\"[^\"]+\"|\'[^\']+\'|\{[^\}]+\})\z/.match(text)
+      if text.length > 2 && /\A(?:"[^\"]+"|'[^\']+'|\{[^\}]+\})\z/.match(text)
       # text already quoted
       elsif !text['\'']
         text = '\'' + text + '\''
@@ -669,6 +666,7 @@ module Magick
 
   # Define IPTC record number:dataset tags for use with Image#get_iptc_dataset
   module IPTC
+    # rubocop:disable Naming/ConstantName
     module Envelope
       Model_Version                          = '1:00'
       Destination                            = '1:05'
@@ -766,6 +764,7 @@ module Magick
     module Post_ObjectData_Descriptor
       Confirmed_ObjectData_Size              = '9:10'
     end
+    # rubocop:enable Naming/ConstantName
   end # module Magick::IPTC
 
   # Ruby-level Magick::Image methods
@@ -837,9 +836,9 @@ module Magick
     # arrays.
     def get_exif_by_entry(*entry)
       ary = []
-      if entry.length.zero?
+      if entry.empty?
         exif_data = self['EXIF:*']
-        exif_data.split("\n").each { |exif| ary.push(exif.split('=')) } if exif_data
+        exif_data&.split("\n")&.each { |exif| ary.push(exif.split('=')) }
       else
         get_exif_by_entry # ensure properties is populated with exif data
         entry.each do |name|
@@ -853,14 +852,12 @@ module Magick
     # Retrieve EXIF data by tag number or all tag/value pairs. The return value is a hash.
     def get_exif_by_number(*tag)
       hash = {}
-      if tag.length.zero?
+      if tag.empty?
         exif_data = self['EXIF:!']
-        if exif_data
-          exif_data.split("\n").each do |exif|
-            tag, value = exif.split('=')
-            tag = tag[1, 4].hex
-            hash[tag] = value
-          end
+        exif_data&.split("\n")&.each do |exif|
+          tag, value = exif.split('=')
+          tag = tag[1, 4].hex
+          hash[tag] = value
         end
       else
         get_exif_by_number # ensure properties is populated with exif data
@@ -1239,6 +1236,7 @@ module Magick
   class ImageList
     include Comparable
     include Enumerable
+
     attr_reader :scene
 
     private
@@ -1288,10 +1286,10 @@ module Magick
     # Allow scene to be set to nil
     def scene=(n)
       if n.nil?
-        Kernel.raise IndexError, 'scene number out of bounds' unless @images.length.zero?
+        Kernel.raise IndexError, 'scene number out of bounds' unless @images.empty?
         @scene = nil
         return
-      elsif @images.length.zero?
+      elsif @images.empty?
         Kernel.raise IndexError, 'scene number out of bounds'
       end
 
@@ -1368,7 +1366,7 @@ module Magick
 
     def []=(*args)
       obj = @images.[]=(*args)
-      if obj && obj.respond_to?(:each)
+      if obj.respond_to?(:each)
         assert_image_array(obj)
         set_current obj.last.__id__
       elsif obj
@@ -1522,7 +1520,7 @@ module Magick
     end
 
     def fill(*args, &block)
-      assert_image args[0] unless block_given?
+      assert_image args[0] unless block
       current = get_current
       @images.fill(*args, &block)
       assert_image_array self
@@ -1542,7 +1540,7 @@ module Magick
     alias select find_all
 
     def from_blob(*blobs, &block)
-      Kernel.raise ArgumentError, 'no blobs given' if blobs.length.zero?
+      Kernel.raise ArgumentError, 'no blobs given' if blobs.empty?
       blobs.each do |b|
         Magick::Image.from_blob(b, &block).each { |n| @images << n }
       end
@@ -1571,9 +1569,8 @@ module Magick
 
     # Call inspect for all the images
     def inspect
-      img = []
-      @images.each { |image| img << image.inspect }
-      img = '[' + img.join(",\n") + "]\nscene=#{@scene}"
+      img = @images.map(&:inspect)
+      '[' + img.join(",\n") + "]\nscene=#{@scene}"
     end
 
     # Set the number of iterations of an animated GIF
@@ -1584,7 +1581,7 @@ module Magick
     end
 
     def last(*args)
-      if args.length.zero?
+      if args.empty?
         a = @images.last
       else
         a = @images.last(*args)
@@ -1616,8 +1613,8 @@ module Magick
     def method_missing(meth_id, *args, &block)
       if @scene
         img = @images[@scene]
-        new_img = img.send(meth_id, *args, &block)
-        img.object_id == new_img.object_id ? self : new_img
+        new_img = img.public_send(meth_id, *args, &block)
+        img.equal?(new_img) ? self : new_img
       else
         super
       end
@@ -1646,7 +1643,7 @@ module Magick
 
     # Ping files and concatenate the new images
     def ping(*files, &block)
-      Kernel.raise ArgumentError, 'no files given' if files.length.zero?
+      Kernel.raise ArgumentError, 'no files given' if files.empty?
       files.each do |f|
         Magick::Image.ping(f, &block).each { |n| @images << n }
       end
@@ -1672,7 +1669,7 @@ module Magick
 
     # Read files and concatenate the new images
     def read(*files, &block)
-      Kernel.raise ArgumentError, 'no files given' if files.length.zero?
+      Kernel.raise ArgumentError, 'no files given' if files.empty?
       files.each do |f|
         Magick::Image.read(f, &block).each { |n| @images << n }
       end
@@ -1735,8 +1732,8 @@ module Magick
       self
     end
 
-    def reverse_each
-      @images.reverse_each { |image| yield(image) }
+    def reverse_each(&block)
+      @images.reverse_each(&block)
       self
     end
 
@@ -1775,9 +1772,7 @@ module Magick
     end
 
     def to_a
-      a = []
-      @images.each { |image| a << image }
-      a
+      @images.map { |image| image }
     end
 
     def uniq
@@ -1811,6 +1806,15 @@ module Magick
     end
     alias indexes values_at
     alias indices values_at
+
+    def destroy!
+      @images.each(&:destroy!)
+      self
+    end
+
+    def destroyed?
+      @images.all?(&:destroyed?)
+    end
   end # Magick::ImageList
 
   class Pixel
